# Copyright 2021-2023 Ian Jauslin
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# two-dimensional point structure

import math

# point in two dimensions
class Point:
    def __init__(self,x,y):
        self.x=x
        self.y=y

    def __add__(self,point):
        return Point(self.x+point.x,self.y+point.y)

    def __sub__(self,point):
        return Point(self.x-point.x,self.y-point.y)

    def __neg__(self):
        return Point(-self.x,-self.y)

    def __mul__(self,a):
        return Point(a*self.x,a*self.y)

    def __truediv__(self,a):
        return Point(self.x/a,self.y/a)

    def __pow__(self,a):
        if a==2:
            return self.dot(self)

    # dot product
    def dot(self,x):
        return self.x*x.x+self.y*x.y

    # integer part
    def int(self):
        return Point(int(self.x),int(self.y))

    # find the closest among a list of points
    def closest(self,points):
        dist=math.inf
        closest=None
        for point in points:
            if (self-point)**2<dist:
                closest=point
                dist=(self-point)**2
        return closest


# L infinity norm
def l_infinity(x):
    return max(abs(x.x),abs(x.y))

# L 2 norm
def l_2(x):
    return math.sqrt(x.x*x.x+x.y*x.y)
